@@ -412,7 +412,16 @@ boost::function<void(void)> libmspub::MSPUBCollector::paintShape(const ShapeInfo
   const Coordinate &coord = info.m_coordinates.get_value_or(Coordinate());
   BorderPosition borderPosition =
     hasBorderArt ? INSIDE_SHAPE : info.m_borderPosition.get_value_or(HALF_INSIDE_SHAPE);
-  ShapeType type = info.m_type.get_value_or(RECTANGLE);
+  ShapeType type;
+  if (info.m_cropType.is_initialized())
+  {
+    type = info.m_cropType.get();
+  }
+  else
+  {
+    type = info.m_type.get_value_or(RECTANGLE);
+  }
+  
   if (hasFill)
   {
     double x, y, height, width;
@@ -1170,7 +1179,11 @@ WPXPropertyList libmspub::MSPUBCollector::getParaStyleProps(const ParagraphStyle
 WPXPropertyList libmspub::MSPUBCollector::getCharStyleProps(const CharacterStyle &style, boost::optional<unsigned> defaultCharStyleIndex) const
 {
   CharacterStyle _nothing = CharacterStyle(false, false, false);
-  const CharacterStyle &defaultCharStyle = defaultCharStyleIndex.is_initialized() && defaultCharStyleIndex.get() < m_defaultCharStyles.size() ? m_defaultCharStyles[defaultCharStyleIndex.get()] : _nothing;
+  if (!defaultCharStyleIndex.is_initialized())
+  {
+    defaultCharStyleIndex = 0;
+  }
+  const CharacterStyle &defaultCharStyle = defaultCharStyleIndex.get() < m_defaultCharStyles.size() ? m_defaultCharStyles[defaultCharStyleIndex.get()] : _nothing;
   WPXPropertyList ret;
   if (style.italic ^ defaultCharStyle.italic)
   {
@@ -1495,4 +1508,9 @@ void libmspub::MSPUBCollector::setMasterPage(unsigned seqNum, unsigned masterPag
   m_masterPagesByPageSeqNum[seqNum] = masterPageSeqNum;
 }
 
+void libmspub::MSPUBCollector::setShapeCropType(unsigned seqNum, ShapeType cropType)
+{
+  m_shapeInfosBySeqNum[seqNum].m_cropType = cropType;
+}
+
 /* vim:set shiftwidth=2 softtabstop=2 expandtab: */
